==> skrooge_0.2.9.orig.tar.gz: skrooge-0.2.9/skgbankmodeler/skgbankobject.h <==
/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
#ifndef SKGBANKOBJECT_H
#define SKGBANKOBJECT_H
/** @file
 * This file is part of Skrooge and defines classes SKGBankObject.
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */

#include "skgnamedobject.h"


class SKGAccountObject;
class SKGDocumentBank;
/**
 * This class manages bank object
 */
class KDE_EXPORT SKGBankObject : public SKGNamedObject
{
        Q_OBJECT;

public:
        /**
         * Constructor
         * @param iDocument the document containing the object
         * @param iID the identifier in @p iTable of the object
         */
        explicit SKGBankObject(const SKGDocument* iDocument=NULL, int iID=0);

        /**
         * Copy constructor
         * @param iObject the object to copy
         */
        SKGBankObject(const SKGBankObject& iObject);

        /**
         * Operator affectation
         * @param iObject the object to copy
         */
        virtual const SKGBankObject& operator= (const SKGObjectBase& iObject);

        /**
         * Destructor
         */
        virtual ~SKGBankObject();

        /**
         * Add an account
         * @param oAccount the created account
         * @return an object managing the error.
         *   @see SKGError
         */
        virtual SKGError addAccount(SKGAccountObject& oAccount);

        /**
         * Get accounts
         * @param oAccountList the list of accounts in this bank
         * @return an object managing the error
         *   @see SKGError
         */
        virtual SKGError getAccounts(SKGListSKGObjectBase& oAccountList) const;

        /**
         * Set the number of the bank
         * @param iNumber the number
         * @return an object managing the error
         *   @see SKGError
         */
        virtual SKGError setNumber(const QString& iNumber);

        /**
         * Get the number of the bank
         * @return the number
         */
        virtual QString getNumber() const;

        /**
         * Set the icon of the bank
         * @param iIcon the icon
         * @return an object managing the error
         *   @see SKGError
         */
        virtual SKGError setIcon(const QString& iIcon);

        /**
         * Get the icon of the bank
         * @return the number
         */
        virtual QString getIcon() const;

        /**
         * Get the current amount
         * @return the current amount
         */
        virtual double getCurrentAmount() const;
};


#endif

==> skrooge-0.5.2.tar.gz: skrooge-0.5.2/skgbankmodeler/skgbankobject.h <==
/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
#ifndef SKGBANKOBJECT_H
#define SKGBANKOBJECT_H
/** @file
 * This file is part of Skrooge and defines classes SKGBankObject.
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */

#include "skgnamedobject.h"
#include "skgbankmodeler_export.h"

class SKGAccountObject;
class SKGDocumentBank;
/**
 * This class manages bank object
 */
class SKGBANKMODELER_EXPORT SKGBankObject : public SKGNamedObject
{
        Q_OBJECT;

public:
        /**
         * Constructor
         * @param iDocument the document containing the object
         * @param iID the identifier in @p iTable of the object
         */
        explicit SKGBankObject(const SKGDocument* iDocument=NULL, int iID=0);

        /**
         * Copy constructor
         * @param iObject the object to copy
         */
        SKGBankObject(const SKGBankObject& iObject);

        /**
         * Operator affectation
         * @param iObject the object to copy
         */
        virtual const SKGBankObject& operator= (const SKGObjectBase& iObject);

        /**
         * Destructor
         */
        virtual ~SKGBankObject();

        /**
         * Add an account
         * @param oAccount the created account
         * @return an object managing the error.
         *   @see SKGError
         */
        virtual SKGError addAccount(SKGAccountObject& oAccount);

        /**
         * Get accounts
         * @param oAccountList the list of accounts in this bank
         * @return an object managing the error
         *   @see SKGError
         */
        virtual SKGError getAccounts(SKGListSKGObjectBase& oAccountList) const;

        /**
         * Set the number of the bank
         * @param iNumber the number
         * @return an object managing the error
         *   @see SKGError
         */
        virtual SKGError setNumber(const QString& iNumber);

        /**
         * Get the number of the bank
         * @return the number
         */
        virtual QString getNumber() const;

        /**
         * Set the icon of the bank
         * @param iIcon the icon
         * @return an object managing the error
         *   @see SKGError
         */
        virtual SKGError setIcon(const QString& iIcon);

        /**
         * Get the icon of the bank
         * @return the number
         */
        virtual QString getIcon() const;

        /**
         * Get the current amount
         * @return the current amount
         */
        virtual double getCurrentAmount() const;
};


#endif
